@@ -2062,8 +2062,8 @@ dec_synth_keystring (SpiDEController *controller, const CORBA_char *keystring)
 		for (i = 0; keysyms[i]; ++i) {
 			if (!dec_synth_keysym (controller, keysyms[i])) {
 #ifdef SPI_DEBUG
-				fprintf (stderr, "could not synthesize %c\n",
-					 (int) keysyms[i]);
+				fprintf (stderr, "could not synthesize %c [%d]\n",
+					 (int) keysyms[i], (int) keysyms[i]);
 #endif
 				retval = FALSE;
 				break;
